package Term::ANSIColor::Gradients::Diverging ;

use strict ;
use warnings ;

our $VERSION = '0.10' ;

our @RED_BLUE_DIV       = (196,160,124,88,244,33,27,21) ;
our @ORANGE_BLUE_DIV    = (214,208,202,244,33,27,21) ;
our @RED_GREEN_DIV      = (196,160,124,244,46,82,118) ;
our @PURPLE_ORANGE_DIV  = (129,93,57,244,172,214,220) ;
our @PINK_GREEN_DIV     = (201,165,129,244,46,82,118) ;
our @BROWN_TEAL_DIV     = (94,130,136,244,37,44,51) ;
our @RED_CYAN_DIV       = (196,160,124,244,51,45,39) ;
our @PURPLE_YELLOW_DIV  = (93,57,244,220,226) ;
our @BLUE_YELLOW_DIV    = (21,27,33,244,220,226) ;
our @MAGENTA_GREEN_DIV  = (201,165,244,118,82,46) ;
our @CRIMSON_SKY_DIV    = (124,160,196,244,51,39,27) ;
our @ORANGE_PURPLE_DIV  = (166,172,208,244,93,57,21) ;
our @GREEN_MAGENTA_DIV  = (46,82,118,244,201,165,129) ;
our @YELLOW_INDIGO_DIV  = (226,220,214,244,57,21,17) ;
our @WARM_COOL_DIV      = (196,208,220,244,45,33,21) ;
our @EARTH_SKY_DIV      = (94,130,166,244,33,27,21) ;
our @FIRE_ICE_DIV       = (196,202,208,214,244,45,39,33,27) ;
our @SUNSET_OCEAN_DIV   = (160,196,208,244,51,39,27) ;
our @ROSE_TEAL_DIV      = (204,211,218,244,44,37,30) ;
our @CORAL_MINT_DIV     = (203,209,215,244,42,36,30) ;
our @CRIMSON_NAVY_DIV   = (88,124,160,196,244,21,20,19) ;
our @AMBER_SLATE_DIV    = (172,178,214,244,240,236,232) ;
our @RUST_AZURE_DIV     = (130,166,196,244,33,27,23) ;
our @BURGUNDY_JADE_DIV  = (52,88,124,244,29,35,41) ;
our @MAROON_AZURE_DIV   = (52,88,160,244,39,33,27) ;

our @RED_BLUE_DIV_CONTRAST      = (14,44,37,30,15,208,214,11) ;
our @ORANGE_BLUE_DIV_CONTRAST   = (27,33,39,15,208,214,11) ;
our @RED_GREEN_DIV_CONTRAST     = (14,44,37,15,13,129,93) ;
our @PURPLE_ORANGE_DIV_CONTRAST = (82,118,154,15,26,27,12) ;
our @PINK_GREEN_DIV_CONTRAST    = (10,10,82,15,13,129,93) ;
our @BROWN_TEAL_DIV_CONTRAST    = (18,25,19,15,124,160,9) ;
our @RED_CYAN_DIV_CONTRAST      = (14,44,37,15,9,9,202) ;
our @PURPLE_YELLOW_DIV_CONTRAST = (118,154,15,12,12) ;
our @BLUE_YELLOW_DIV_CONTRAST   = (11,214,208,15,12,12) ;
our @MAGENTA_GREEN_DIV_CONTRAST = (10,10,15,93,129,13) ;
our @CRIMSON_SKY_DIV_CONTRAST   = (37,44,14,15,9,202,214) ;
our @ORANGE_PURPLE_DIV_CONTRAST = (32,26,33,15,118,154,11) ;
our @GREEN_MAGENTA_DIV_CONTRAST = (13,129,93,15,10,10,82) ;
our @YELLOW_INDIGO_DIV_CONTRAST = (12,12,27,15,154,11,58) ;
our @WARM_COOL_DIV_CONTRAST     = (14,33,12,15,9,208,11) ;
our @EARTH_SKY_DIV_CONTRAST     = (18,25,32,15,208,214,11) ;
our @FIRE_ICE_DIV_CONTRAST      = (14,39,33,27,15,9,202,208,214) ;
our @SUNSET_OCEAN_DIV_CONTRAST  = (44,14,33,15,9,202,214) ;
our @ROSE_TEAL_DIV_CONTRAST     = (86,122,158,15,160,124,88) ;
our @CORAL_MINT_DIV_CONTRAST    = (87,81,75,15,161,124,88) ;
our @CRIMSON_NAVY_DIV_CONTRAST  = (30,37,44,14,15,11,184,142) ;
our @AMBER_SLATE_DIV_CONTRAST   = (26,20,27,15,15,15,15) ;
our @RUST_AZURE_DIV_CONTRAST    = (25,32,14,15,208,214,52) ;
our @BURGUNDY_JADE_DIV_CONTRAST = (23,30,37,15,88,125,162) ;
our @MAROON_AZURE_DIV_CONTRAST  = (23,30,44,15,202,208,214) ;

our %GRADIENTS =
	(
	RED_BLUE_DIV      => \@RED_BLUE_DIV,
	ORANGE_BLUE_DIV   => \@ORANGE_BLUE_DIV,
	RED_GREEN_DIV     => \@RED_GREEN_DIV,
	PURPLE_ORANGE_DIV => \@PURPLE_ORANGE_DIV,
	PINK_GREEN_DIV    => \@PINK_GREEN_DIV,
	BROWN_TEAL_DIV    => \@BROWN_TEAL_DIV,
	RED_CYAN_DIV      => \@RED_CYAN_DIV,
	PURPLE_YELLOW_DIV => \@PURPLE_YELLOW_DIV,
	BLUE_YELLOW_DIV   => \@BLUE_YELLOW_DIV,
	MAGENTA_GREEN_DIV => \@MAGENTA_GREEN_DIV,
	CRIMSON_SKY_DIV   => \@CRIMSON_SKY_DIV,
	ORANGE_PURPLE_DIV => \@ORANGE_PURPLE_DIV,
	GREEN_MAGENTA_DIV => \@GREEN_MAGENTA_DIV,
	YELLOW_INDIGO_DIV => \@YELLOW_INDIGO_DIV,
	WARM_COOL_DIV     => \@WARM_COOL_DIV,
	EARTH_SKY_DIV     => \@EARTH_SKY_DIV,
	FIRE_ICE_DIV      => \@FIRE_ICE_DIV,
	SUNSET_OCEAN_DIV  => \@SUNSET_OCEAN_DIV,
	ROSE_TEAL_DIV     => \@ROSE_TEAL_DIV,
	CORAL_MINT_DIV    => \@CORAL_MINT_DIV,
	CRIMSON_NAVY_DIV  => \@CRIMSON_NAVY_DIV,
	AMBER_SLATE_DIV   => \@AMBER_SLATE_DIV,
	RUST_AZURE_DIV    => \@RUST_AZURE_DIV,
	BURGUNDY_JADE_DIV => \@BURGUNDY_JADE_DIV,
	MAROON_AZURE_DIV  => \@MAROON_AZURE_DIV,
	) ;

our %CONTRAST =
	(
	RED_BLUE_DIV      => \@RED_BLUE_DIV_CONTRAST,
	ORANGE_BLUE_DIV   => \@ORANGE_BLUE_DIV_CONTRAST,
	RED_GREEN_DIV     => \@RED_GREEN_DIV_CONTRAST,
	PURPLE_ORANGE_DIV => \@PURPLE_ORANGE_DIV_CONTRAST,
	PINK_GREEN_DIV    => \@PINK_GREEN_DIV_CONTRAST,
	BROWN_TEAL_DIV    => \@BROWN_TEAL_DIV_CONTRAST,
	RED_CYAN_DIV      => \@RED_CYAN_DIV_CONTRAST,
	PURPLE_YELLOW_DIV => \@PURPLE_YELLOW_DIV_CONTRAST,
	BLUE_YELLOW_DIV   => \@BLUE_YELLOW_DIV_CONTRAST,
	MAGENTA_GREEN_DIV => \@MAGENTA_GREEN_DIV_CONTRAST,
	CRIMSON_SKY_DIV   => \@CRIMSON_SKY_DIV_CONTRAST,
	ORANGE_PURPLE_DIV => \@ORANGE_PURPLE_DIV_CONTRAST,
	GREEN_MAGENTA_DIV => \@GREEN_MAGENTA_DIV_CONTRAST,
	YELLOW_INDIGO_DIV => \@YELLOW_INDIGO_DIV_CONTRAST,
	WARM_COOL_DIV     => \@WARM_COOL_DIV_CONTRAST,
	EARTH_SKY_DIV     => \@EARTH_SKY_DIV_CONTRAST,
	FIRE_ICE_DIV      => \@FIRE_ICE_DIV_CONTRAST,
	SUNSET_OCEAN_DIV  => \@SUNSET_OCEAN_DIV_CONTRAST,
	ROSE_TEAL_DIV     => \@ROSE_TEAL_DIV_CONTRAST,
	CORAL_MINT_DIV    => \@CORAL_MINT_DIV_CONTRAST,
	CRIMSON_NAVY_DIV  => \@CRIMSON_NAVY_DIV_CONTRAST,
	AMBER_SLATE_DIV   => \@AMBER_SLATE_DIV_CONTRAST,
	RUST_AZURE_DIV    => \@RUST_AZURE_DIV_CONTRAST,
	BURGUNDY_JADE_DIV => \@BURGUNDY_JADE_DIV_CONTRAST,
	MAROON_AZURE_DIV  => \@MAROON_AZURE_DIV_CONTRAST,
	) ;

1 ;
