package Term::ANSIColor::Gradients::Accessibility ;

use strict ;
use warnings ;

our $VERSION = '0.10' ;

our @ACC_BLUE_ORANGE   = (21,27,33,39,208,214,220) ;
our @ACC_HIGH_CONTRAST = (16,232,240,248,252,255) ;
our @ACC_DEUTER_BLUE   = (17,18,19,20,21,27,33,39) ;
our @ACC_DEUTER_ORANGE = (130,166,172,202,208,214) ;
our @ACC_PROTO_BLUES   = (17,19,21,27,33,39,45,51) ;
our @ACC_TRIT_RG       = (196,160,124,88,34,40,46) ;
our @ACC_MONO_CONTRAST = (16,236,240,244,248,252,255) ;
our @ACC_BLUE_YELLOW   = (21,27,33,39,220,226,227,228) ;
our @ACC_OKABE_BLUE    = (21,33,39,45,87) ;
our @ACC_OKABE_ORANGE  = (130,166,172,202,208) ;
our @ACC_WONG_ORANGE   = (214,208,202,196) ;
our @ACC_WONG_BLUE     = (21,27,33,39) ;
our @ACC_BLUE_RAMP     = (18,19,20,21,27,33,39,45) ;
our @ACC_ORANGE_RAMP   = (130,136,172,178,214,220) ;
our @ACC_HC_PAIRS      = (16,21,196,226,46,201) ;
our @ACC_GRAYSCALE     = (232,234,236,238,240,242,244,246,248,250,252,254) ;
our @ACC_COOL          = (17,19,21,23,29,35,41,47) ;
our @ACC_WARM          = (52,88,124,160,166,172,202,208) ;
our @ACC_BLUE_AMBER    = (21,27,33,39,172,178,214,220) ;
our @ACC_VIOLET_GOLD   = (57,93,129,165,136,172,220) ;
our @ACC_NAVY_CORAL    = (17,19,21,27,196,202,208) ;
our @ACC_TEAL_ORANGE   = (23,29,35,41,166,172,178,208) ;
our @ACC_INDIGO_AMBER  = (53,54,55,56,57,172,178,214) ;
our @ACC_AZURE_BRONZE  = (27,33,39,45,136,172,130) ;
our @ACC_SAFE_SPECTRUM = (17,21,35,40,172,208,201,57) ;

our @ACC_BLUE_ORANGE_CONTRAST   = (11,214,208,202,33,27,12) ;
our @ACC_HIGH_CONTRAST_CONTRAST = (15,15,15,0,0,0) ;
our @ACC_DEUTER_BLUE_CONTRAST   = (58,100,142,184,11,214,208,202) ;
our @ACC_DEUTER_ORANGE_CONTRAST = (25,32,26,39,33,27) ;
our @ACC_PROTO_BLUES_CONTRAST   = (58,142,11,214,208,202,9,9) ;
our @ACC_TRIT_RG_CONTRAST       = (14,44,37,30,127,164,13) ;
our @ACC_MONO_CONTRAST_CONTRAST = (15,15,15,15,0,0,0) ;
our @ACC_BLUE_YELLOW_CONTRAST   = (11,214,208,202,12,12,63,105) ;
our @ACC_OKABE_BLUE_CONTRAST    = (11,208,202,9,203) ;
our @ACC_OKABE_ORANGE_CONTRAST  = (25,32,26,39,33) ;
our @ACC_WONG_ORANGE_CONTRAST   = (27,33,39,14) ;
our @ACC_WONG_BLUE_CONTRAST     = (11,214,208,202) ;
our @ACC_BLUE_RAMP_CONTRAST     = (100,142,184,11,214,208,202,9) ;
our @ACC_ORANGE_RAMP_CONTRAST   = (25,19,26,20,27,12) ;
our @ACC_HC_PAIRS_CONTRAST      = (15,11,14,12,13,10) ;
our @ACC_GRAYSCALE_CONTRAST     = (15,15,15,15,15,15,15,0,0,0,0,0) ;
our @ACC_COOL_CONTRAST          = (58,142,11,52,88,125,162,199) ;
our @ACC_WARM_CONTRAST          = (23,30,37,44,32,26,39,33) ;
our @ACC_BLUE_AMBER_CONTRAST    = (11,214,208,202,26,20,27,12) ;
our @ACC_VIOLET_GOLD_CONTRAST   = (154,118,82,10,19,26,12) ;
our @ACC_NAVY_CORAL_CONTRAST    = (58,142,11,214,14,39,33) ;
our @ACC_TEAL_ORANGE_CONTRAST   = (52,88,125,162,32,26,20,33) ;
our @ACC_INDIGO_AMBER_CONTRAST  = (22,28,70,112,154,26,20,27) ;
our @ACC_AZURE_BRONZE_CONTRAST  = (214,208,202,9,19,26,25) ;
our @ACC_SAFE_SPECTRUM_CONTRAST = (58,11,125,164,26,33,10,154) ;

our %GRADIENTS =
	(
	ACC_BLUE_ORANGE   => \@ACC_BLUE_ORANGE,
	ACC_HIGH_CONTRAST => \@ACC_HIGH_CONTRAST,
	ACC_DEUTER_BLUE   => \@ACC_DEUTER_BLUE,
	ACC_DEUTER_ORANGE => \@ACC_DEUTER_ORANGE,
	ACC_PROTO_BLUES   => \@ACC_PROTO_BLUES,
	ACC_TRIT_RG       => \@ACC_TRIT_RG,
	ACC_MONO_CONTRAST => \@ACC_MONO_CONTRAST,
	ACC_BLUE_YELLOW   => \@ACC_BLUE_YELLOW,
	ACC_OKABE_BLUE    => \@ACC_OKABE_BLUE,
	ACC_OKABE_ORANGE  => \@ACC_OKABE_ORANGE,
	ACC_WONG_ORANGE   => \@ACC_WONG_ORANGE,
	ACC_WONG_BLUE     => \@ACC_WONG_BLUE,
	ACC_BLUE_RAMP     => \@ACC_BLUE_RAMP,
	ACC_ORANGE_RAMP   => \@ACC_ORANGE_RAMP,
	ACC_HC_PAIRS      => \@ACC_HC_PAIRS,
	ACC_GRAYSCALE     => \@ACC_GRAYSCALE,
	ACC_COOL          => \@ACC_COOL,
	ACC_WARM          => \@ACC_WARM,
	ACC_BLUE_AMBER    => \@ACC_BLUE_AMBER,
	ACC_VIOLET_GOLD   => \@ACC_VIOLET_GOLD,
	ACC_NAVY_CORAL    => \@ACC_NAVY_CORAL,
	ACC_TEAL_ORANGE   => \@ACC_TEAL_ORANGE,
	ACC_INDIGO_AMBER  => \@ACC_INDIGO_AMBER,
	ACC_AZURE_BRONZE  => \@ACC_AZURE_BRONZE,
	ACC_SAFE_SPECTRUM => \@ACC_SAFE_SPECTRUM,
	) ;

our %CONTRAST =
	(
	ACC_BLUE_ORANGE   => \@ACC_BLUE_ORANGE_CONTRAST,
	ACC_HIGH_CONTRAST => \@ACC_HIGH_CONTRAST_CONTRAST,
	ACC_DEUTER_BLUE   => \@ACC_DEUTER_BLUE_CONTRAST,
	ACC_DEUTER_ORANGE => \@ACC_DEUTER_ORANGE_CONTRAST,
	ACC_PROTO_BLUES   => \@ACC_PROTO_BLUES_CONTRAST,
	ACC_TRIT_RG       => \@ACC_TRIT_RG_CONTRAST,
	ACC_MONO_CONTRAST => \@ACC_MONO_CONTRAST_CONTRAST,
	ACC_BLUE_YELLOW   => \@ACC_BLUE_YELLOW_CONTRAST,
	ACC_OKABE_BLUE    => \@ACC_OKABE_BLUE_CONTRAST,
	ACC_OKABE_ORANGE  => \@ACC_OKABE_ORANGE_CONTRAST,
	ACC_WONG_ORANGE   => \@ACC_WONG_ORANGE_CONTRAST,
	ACC_WONG_BLUE     => \@ACC_WONG_BLUE_CONTRAST,
	ACC_BLUE_RAMP     => \@ACC_BLUE_RAMP_CONTRAST,
	ACC_ORANGE_RAMP   => \@ACC_ORANGE_RAMP_CONTRAST,
	ACC_HC_PAIRS      => \@ACC_HC_PAIRS_CONTRAST,
	ACC_GRAYSCALE     => \@ACC_GRAYSCALE_CONTRAST,
	ACC_COOL          => \@ACC_COOL_CONTRAST,
	ACC_WARM          => \@ACC_WARM_CONTRAST,
	ACC_BLUE_AMBER    => \@ACC_BLUE_AMBER_CONTRAST,
	ACC_VIOLET_GOLD   => \@ACC_VIOLET_GOLD_CONTRAST,
	ACC_NAVY_CORAL    => \@ACC_NAVY_CORAL_CONTRAST,
	ACC_TEAL_ORANGE   => \@ACC_TEAL_ORANGE_CONTRAST,
	ACC_INDIGO_AMBER  => \@ACC_INDIGO_AMBER_CONTRAST,
	ACC_AZURE_BRONZE  => \@ACC_AZURE_BRONZE_CONTRAST,
	ACC_SAFE_SPECTRUM => \@ACC_SAFE_SPECTRUM_CONTRAST,
	) ;

1 ;
